@@ -723,6 +723,32 @@ class RepeatableRandomSequence(object):
             low, high = high, low
         return low + (high - low) * sqrt(u * c)
 
+    def uniformproduct(self, n: int) -> float:
+        r"""Sample from a distribution whose values are the product of N
+        uniformly distributed variables.
+
+        This distribution has the following PDF
+
+        .. math::
+
+            \text{P}(x) =
+            \begin{cases}
+            \frac{(-1)^{n-1} log^{n-1}(x)}{(n - 1)!} &
+            \text{for } x \in [0, 1) \\
+            0 & \text{otherwise}
+            \end{cases}
+
+        Raises:
+            ValueError: if `n` is not at least 1.
+        """
+        if n < 1:
+            raise ValueError('n must be at least 1.')
+        result: float = 1.0
+        with self.cascade():
+            for _ in range(n):
+                result *= self.random()
+        return result
+
     def chance(self, p: float) -> bool:
         """Returns ``True`` with probability `p`, else ``False``.
 
@@ -1009,7 +1035,7 @@ class RepeatableRandomSequence(object):
         # Implementation based on MSVC standard library.
         # Supports limits greater than _BLOCK_SIZE_BITS bits long
         with self.cascade():
-            for i in range(self._MAX_ITERATIONS):
+            for _ in range(self._MAX_ITERATIONS):
                 result = 0
                 mask = 0
                 while mask < limit - 1:
@@ -1023,8 +1049,8 @@ class RepeatableRandomSequence(object):
                 if (result // limit < mask // limit) or \
                         (mask % limit == limit - 1):
                     return result % limit
-            else:
-                raise RuntimeError('Could not make a random '
+
+            raise RuntimeError('Could not make a random '
                                    'selection within limit.')
 
     def _gauss_impl(self) -> Tuple[float, float]:
